<?php

/**
 * @file
 * Documents API functions for Avatar Approval module.
 */

/**
 * Avatar approval API hook
 *
 * This API hook is registered as soon as you create a yourmodule_avatarapproval()
 * in yourmodule. It will be invoked when the avatarapproval module needs
 * to display an avatar submission form and when a new avatar is being
 * uploaded. Thus, the function parameters are the actual Drupal Form API
 * representation of the form and can be useful to perform your own module
 * logic on avatar uploads.
 *
 * The example below is the avatarapproval module binding to the user form
 * so that the picture upload field is moderated. You can define it to handle
 * your forms picture upload fields in an analogous way
 *
 * @param $form
 * 		The Form API form that has been posted
 * @param $form_state
 * 		The Form API form state that has been posted along with the $form
 * @return
 * 		An associative array with the following keys:
 * 		- xxx	: The form name where avatarapproval should monitor for possible
 * 				avatar uploads.
 * 				By default, avatarapproval defines hooks in the user profile form,
 * 				thus the avatarapproval implementations set will always contain
 * 				at least a 'user_profile_form' entry.
 * 			- avatar_owner: The Drupal user object corresponding to the avatar
 *    			owner, which chan be different from the submissor in case an user
 *    			role has the permission to change other users pictures.
 *    	- upload_field: The name of the picture upload field of the forementioned
 *    			form, whose content will be treated as a new avatar upload. It can be an
 *    			array, in which case the name will be the last of the entries while
 *    			those before will be the hierarchy to orderly follow to resolve the
 *    			form field in the fAPI array
 *    	- delete_field: The name of the picture delete field of the forementioned
 *    			form, so that it will be hidden on approval awaiting. It can be an
 *    			array, in which case the name will be the last of the entries while
 *    			those before will be the hierarchy to orderly follow to resolve the
 *    			form field in the fAPI array
 *    	- show_file_path: If set, the forementioned form will be altered to
 *    			display the current avatar filesystem path to the moderators.
 *    			NOTE: This parameter is used only in form initialization.
 *    	- late_submit_handler: A flag that signals to put the avatarapproval
 *    			form submit handler last (TRUE) or first (FALSE, default) on the
 *    			form submission handler stack.
 *    			NOTE: This parameter is used only in form initialization.
 */

function hook_avatarapproval($form, $form_state) {
	// Deduce edited account from form, or default to logged user
	$account = (isset($form['#user']) ? $form['#user'] : $GLOBALS['user']);
  // Return settings for the user profile edit form
  $settings = array(
    'user_profile_form' => array(
      'avatar_owner' => $account,
      'upload_field' => array('picture', 'picture_upload'),
  		'delete_field' => array('picture', 'picture_delete'),
      'show_file_path' => TRUE,
      'late_submit_handler' => FALSE,
    ),
  );
  return $settings;
}